### Contexto

(*describir las condiciones o entorno de partida*)

* NanoCore version:

(*otros ejemplos*)
* Python version:
* Operating System:

### Problema

Describe que querias obtener
Dinos que pasó, qué fue mal, y qué esperabas que sucediera

### Pasos Realizados

(*incluir contexto o pasos realidados*)

1. paso 1
1. paso 2
1. paso 3

```
Copia los comandos que ejecutastes para poder reproducir el caso
Si hubo un crash, incluye la traza aqui por favor.
```
4. paso 4
1. paso 4
